@@ -17,10 +17,10 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 	"sigs.k8s.io/yaml"
 
-	mcoshared "github.com/open-cluster-management/multicluster-observability-operator/api/shared"
-	mcov1beta2 "github.com/open-cluster-management/multicluster-observability-operator/api/v1beta2"
-	mcoconfig "github.com/open-cluster-management/multicluster-observability-operator/pkg/config"
-	observatoriumv1alpha1 "github.com/open-cluster-management/observatorium-operator/api/v1alpha1"
+	mcoshared "github.com/stolostron/multicluster-observability-operator/api/shared"
+	mcov1beta2 "github.com/stolostron/multicluster-observability-operator/api/v1beta2"
+	mcoconfig "github.com/stolostron/multicluster-observability-operator/pkg/config"
+	observatoriumv1alpha1 "github.com/stolostron/observatorium-operator/api/v1alpha1"
 )
 
 var (
